.. _routines:

*****************************
Routines and objects by topic
*****************************

In this chapter, routine docstrings are presented, grouped by functionality.
Many docstrings contain example code, which demonstrates basic usage
of the routine.

A convenient way to execute examples is the ``%doctest_mode`` mode of
IPython, which allows for pasting of multi-line examples and preserves
indentation.

.. Note: this is a listing of functionality grouped by topic. By design this is
   opinionated and incomplete. Please don't add niche/legacy/deprecated topics,
   submodules or doc pages here. It is only meant to give the average user of
   the Python API guidance when looking for functionality, not to cover every
   last corner of NumPy. For that, we have per-module function/object listings
   as well as a search box.

.. toctree::
   :maxdepth: 1

   constants
   routines.array-creation
   routines.array-manipulation
   routines.bitwise
   routines.strings
   routines.datetime
   routines.dtype
   routines.emath
   routines.err
   routines.exceptions
   routines.fft
   routines.functional
   routines.io
   routines.indexing
   routines.linalg
   routines.logic
   routines.ma
   routines.math
   routines.other
   routines.polynomials
   random/index
   routines.set
   routines.sort
   routines.statistics
   routines.testing
   routines.window

